@@ -3,7 +3,7 @@ package CLI::Driver::Action;
 use Modern::Perl;
 use Moose;
 use namespace::autoclean;
-use Method::Signatures;
+use Kavorka '-all';
 use Data::Printer alias => 'pdump';
 use CLI::Driver::Class;
 use CLI::Driver::Method;
@@ -193,7 +193,7 @@ method do {
 	if (@ARGV) {
 		$self->die( "extra args detected: @ARGV");
 	}
-	
+    
     return $obj->$method_name(%sig);
 }
 
